@@ -12,10 +12,6 @@
 
    Copyright 2022, HSPyLib team
 """
-import contextlib
-import logging as log
-from typing import Generic, List, Optional, Set, Tuple, TypeVar
-
 from cassandra import UnresolvableContactPoints
 from cassandra.auth import PlainTextAuthProvider
 from cassandra.cluster import Cluster, NoHostAvailable
@@ -28,8 +24,12 @@ from hspylib.core.metaclass.singleton import AbstractSingleton
 from hspylib.core.namespace import Namespace
 from hspylib.core.tools.text_tools import quote
 from retry import retry
+from typing import Generic, List, Optional, Set, Tuple, TypeVar
 
-E = TypeVar('E', bound=CrudEntity)
+import contextlib
+import logging as log
+
+E = TypeVar("E", bound=CrudEntity)
 
 
 class CassandraRepository(Generic[E], DBRepository[E, CassandraConfiguration], metaclass=AbstractSingleton):
@@ -60,14 +60,19 @@ class CassandraRepository(Generic[E], DBRepository[E, CassandraConfiguration], m
         auth_provider = PlainTextAuthProvider(username=self.username, password=self.password)
         if self.secure_bundle_path:
             log.info("%s Using Astra Security Bundle: %s", self.logname, self.secure_bundle_path)
-            cloud_config = {'secure_connect_bundle': self.secure_bundle_path}
-            cursor = Cluster(protocol_version=self.protocol_version, auth_provider=auth_provider,
-                             cloud=cloud_config)
+            cloud_config = {"secure_connect_bundle": self.secure_bundle_path}
+            cursor = Cluster(protocol_version=self.protocol_version, auth_provider=auth_provider, cloud=cloud_config)
         else:
-            log.info(f"{self.logname} Attempt to connect to Astra: "
-                     f"{self.username}@{self.hostname}:{self.port}/{self.database}")
-            cursor = Cluster(protocol_version=self.protocol_version, auth_provider=auth_provider,
-                             contact_points=[self.hostname], port=self.port)
+            log.info(
+                f"{self.logname} Attempt to connect to Astra: "
+                f"{self.username}@{self.hostname}:{self.port}/{self.database}"
+            )
+            cursor = Cluster(
+                protocol_version=self.protocol_version,
+                auth_provider=auth_provider,
+                contact_points=[self.hostname],
+                port=self.port,
+            )
         session = cursor.connect()
         cursor.connect_timeout = self.connect_timeout
         session.default_timeout = self.default_timeout
@@ -92,9 +97,11 @@ class CassandraRepository(Generic[E], DBRepository[E, CassandraConfiguration], m
         with self._session() as dbs:
             try:
                 rows = []
-                log.debug(f"{self.logname} Executing SQL statement {sql_statement} [ssid={hash(dbs)}]:\n"
-                          f"\t|-Arguments: {str([f'{k}={v}' for k, v in kwargs.items()])}\n"
-                          f"\t|-Statement: {sql_statement}")
+                log.debug(
+                    f"{self.logname} Executing SQL statement {sql_statement} [ssid={hash(dbs)}]:\n"
+                    f"\t|-Arguments: {str([f'{k}={v}' for k, v in kwargs.items()])}\n"
+                    f"\t|-Statement: {sql_statement}"
+                )
                 rs = dbs.execute(sql_statement, **kwargs)
                 if rs.current_rows:
                     list(map(rows.append, rs.current_rows))
@@ -111,31 +118,31 @@ class CassandraRepository(Generic[E], DBRepository[E, CassandraConfiguration], m
 
     def delete_by_id(self, entity_id: Identity) -> None:
         clauses = [f"{k} = {quote(v)}" for k, v in zip(entity_id.attributes, entity_id.values)]
-        sql = f"DELETE FROM {self.database}.{self.table_name()} WHERE " + ' AND '.join(clauses)
+        sql = f"DELETE FROM {self.database}.{self.table_name()} WHERE " + " AND ".join(clauses)
         self.execute(sql)
 
     def delete_all(self, entities: List[E]) -> None:
         values, s = [], entities[0]
         list(map(lambda e: values.append(str(e.values)), entities))
-        sql = f"DELETE FROM {self.database}.{self.table_name()} " \
-              f"WHERE ({s.as_columns()}) IN ({', '.join(values)}) "
+        sql = f"DELETE FROM {self.database}.{self.table_name()} " f"WHERE ({s.as_columns()}) IN ({', '.join(values)}) "
         self.execute(sql)
 
     def save(self, entity: E) -> None:
         columns, _ = entity.as_columns(), set(entity.identity.attributes)
-        sql = f"INSERT INTO {self.database}.{self.table_name()} " \
-              f"({columns}) VALUES {entity.values} "
+        sql = f"INSERT INTO {self.database}.{self.table_name()} " f"({columns}) VALUES {entity.values} "
         self.execute(sql)
 
     def save_all(self, entities: List[E]) -> None:
         values, sample, inserts = [], entities[0], []
         columns, _ = sample.as_columns(), set(sample.identity.attributes)
         list(map(lambda e: values.append(str(e.values)), entities))
-        list(map(lambda v: inserts.append(
-            f"INSERT INTO {self.database}.{self.table_name()} ({columns}) VALUES {v} "), values))
-        sql = f"BEGIN BATCH " \
-              f"{'; '.join(inserts)} " \
-              f"APPLY BATCH;"
+        list(
+            map(
+                lambda v: inserts.append(f"INSERT INTO {self.database}.{self.table_name()} ({columns}) VALUES {v} "),
+                values,
+            )
+        )
+        sql = f"BEGIN BATCH " f"{'; '.join(inserts)} " f"APPLY BATCH;"
         self.execute(sql)
 
     def find_all(
@@ -143,27 +150,27 @@ class CassandraRepository(Generic[E], DBRepository[E, CassandraConfiguration], m
         fields: Optional[Set[str]] = None,
         filters: Optional[Namespace] = None,
         order_bys: Optional[List[str]] = None,
-        limit: int = 500, offset: int = 0) -> List[E]:
+        limit: int = 500,
+        offset: int = 0,
+    ) -> List[E]:
 
-        fields = '*' if not fields else ', '.join(fields)
+        fields = "*" if not fields else ", ".join(fields)
         clauses = list(filter(None, filters.values)) if filters else None
         orders = list(filter(None, order_bys)) if order_bys and clauses else None  # Order by require filters
-        sql = f"SELECT {fields} FROM {self.database}.{self.table_name()} " \
-              f"{('WHERE ' + ' AND '.join(clauses)) if clauses else ''} " \
-              f"{('ORDER BY ' + ', '.join(orders)) if orders else ''} " \
-              f"LIMIT {limit}"
+        sql = (
+            f"SELECT {fields} FROM {self.database}.{self.table_name()} "
+            f"{('WHERE ' + ' AND '.join(clauses)) if clauses else ''} "
+            f"{('ORDER BY ' + ', '.join(orders)) if orders else ''} "
+            f"LIMIT {limit}"
+        )
 
         return list(map(self.to_entity_type, self.execute(sql)[1]))
 
-    def find_by_id(
-        self,
-        entity_id: Identity,
-        fields: Optional[Set[str]] = None) -> Optional[E]:
+    def find_by_id(self, entity_id: Identity, fields: Optional[Set[str]] = None) -> Optional[E]:
 
-        fields = '*' if not fields else ', '.join(fields)
+        fields = "*" if not fields else ", ".join(fields)
         clauses = [f"{k} = {quote(v)}" for k, v in zip(entity_id.attributes, entity_id.values)]
-        sql = f"SELECT {fields} FROM {self.database}.{self.table_name()} " \
-              f"WHERE {' AND '.join(clauses)}"
+        sql = f"SELECT {fields} FROM {self.database}.{self.table_name()} " f"WHERE {' AND '.join(clauses)}"
         result = next((e for e in self.execute(sql)[1]), None)
 
         return self.to_entity_type(result) if result else None
