@@ -12,20 +12,18 @@
 
    Copyright 2022, HSPyLib team
 """
-from typing import Generic, List, Optional, TypeVar
-
 from datasource.crud_entity import CrudEntity
 from datasource.crud_repository import CrudRepository
 from datasource.identity import Identity
 from hspylib.core.metaclass.singleton import AbstractSingleton
 from hspylib.core.namespace import Namespace
+from typing import Generic, List, Optional, TypeVar
 
-E = TypeVar('E', bound=CrudEntity)
-R = TypeVar('R', bound=CrudRepository)
+E = TypeVar("E", bound=CrudEntity)
+R = TypeVar("R", bound=CrudRepository)
 
 
 class CrudService(Generic[R, E], metaclass=AbstractSingleton):
-
     def __init__(self, repository: R):
         self._repository = repository
 
