@@ -12,25 +12,20 @@
 
    Copyright 2022, HSPyLib team
 """
-from typing import Optional
-
 from hspylib.core.config.app_config import AppConfigs
+from typing import Optional
 
 
 class DBConfiguration(AppConfigs):
     """TODO"""
 
-    def __init__(
-        self,
-        resource_dir: str,
-        filename: Optional[str] = None,
-        profile: Optional[str] = None):
+    def __init__(self, resource_dir: str, filename: Optional[str] = None, profile: Optional[str] = None):
         super().__init__(resource_dir, filename, profile)
-        self._hostname = self['datasource.hostname']
-        self._port = self.get_int('datasource.port')
-        self._username = self['datasource.username']
-        self._password = self['datasource.password']
-        self._database = self['datasource.database']
+        self._hostname = self["datasource.hostname"]
+        self._port = self.get_int("datasource.port")
+        self._username = self["datasource.username"]
+        self._password = self["datasource.password"]
+        self._database = self["datasource.database"]
 
     @property
     def hostname(self) -> str:
