@@ -12,25 +12,25 @@
 
    Copyright 2022, HSPyLib team
 """
-import contextlib
 from abc import abstractmethod
-from typing import Any, Generic, Iterable, Optional, Tuple, TypeVar
-
 from datasource.crud_entity import CrudEntity
 from datasource.crud_repository import CrudRepository
 from datasource.db_configuration import DBConfiguration
 from hspylib.core.metaclass.singleton import AbstractSingleton
 from retry import retry
+from typing import Any, Generic, Iterable, Optional, Tuple, TypeVar
+
+import contextlib
 
 # Stereotypes
-Connection = TypeVar('Connection', bound=Any)
-Cursor = TypeVar('Cursor', bound=Any)
-Session = TypeVar('Session', bound=Any)
-ResultSet = TypeVar('ResultSet', bound=Iterable)
+Connection = TypeVar("Connection", bound=Any)
+Cursor = TypeVar("Cursor", bound=Any)
+Session = TypeVar("Session", bound=Any)
+ResultSet = TypeVar("ResultSet", bound=Iterable)
 
 # Generics
-E = TypeVar('E', bound=CrudEntity)
-C = TypeVar('C', bound=DBConfiguration)
+E = TypeVar("E", bound=CrudEntity)
+C = TypeVar("C", bound=DBConfiguration)
 
 
 class DBRepository(Generic[E, C], CrudRepository[E], metaclass=AbstractSingleton):
