@@ -13,11 +13,7 @@
    Copyright 2022, HSPyLib team
 """
 
-import json
-import logging as log
 from abc import abstractmethod
-from typing import Any, Generic, List, Optional, TypeVar
-
 from datasource.crud_entity import CrudEntity
 from datasource.firebase.firebase_configuration import FirebaseConfiguration
 from datasource.identity import Identity
@@ -27,8 +23,12 @@ from hspylib.core.preconditions import check_not_none
 from hspylib.modules.fetch.fetch import delete, get, put
 from hspylib.modules.fetch.http_response import HttpResponse
 from requests.exceptions import HTTPError
+from typing import Any, Generic, List, Optional, TypeVar
 
-E = TypeVar('E', bound=CrudEntity)
+import json
+import logging as log
+
+E = TypeVar("E", bound=CrudEntity)
 
 
 class FirebaseRepository(Generic[E], metaclass=AbstractSingleton):
@@ -47,13 +47,13 @@ class FirebaseRepository(Generic[E], metaclass=AbstractSingleton):
 
     @staticmethod
     def quote(value: Any) -> str:
-        """Quote or double quote the value according to the value type. """
+        """Quote or double quote the value according to the value type."""
         if isinstance(value, bool):
-            return f'{str(value).lower()}'
+            return f"{str(value).lower()}"
         if isinstance(value, int | float):
             return str(value)
 
-        return f'"{value}"' if value.startswith('\'') and value.endswith('\'') else f"'{value}'"
+        return f'"{value}"' if value.startswith("'") and value.endswith("'") else f"'{value}'"
 
     def __init__(self, config: FirebaseConfiguration):
         self._payload = None
@@ -68,7 +68,7 @@ class FirebaseRepository(Generic[E], metaclass=AbstractSingleton):
     @property
     def logname(self) -> str:
         """TODO"""
-        return self.__class__.__name__.split('_', maxsplit=1)[0]
+        return self.__class__.__name__.split("_", maxsplit=1)[0]
 
     @property
     def config(self) -> FirebaseConfiguration:
@@ -101,10 +101,10 @@ class FirebaseRepository(Generic[E], metaclass=AbstractSingleton):
 
     def delete_by_id(self, entity_id: Identity) -> None:
         """Deletes the given entity by it's Id from the Firebase store"""
-        ids = '.'.join(entity_id.values)
-        url = f'{self._config.url(self.table_name())}/{ids}.json'
-        log.debug('Deleting firebase entry: \n\t|-Id=%s\n\t|-From %s', entity_id, url)
-        self._assert_response(delete(url), f'Unable to delete from={url}')
+        ids = ".".join(entity_id.values)
+        url = f"{self._config.url(self.table_name())}/{ids}.json"
+        log.debug("Deleting firebase entry: \n\t|-Id=%s\n\t|-From %s", entity_id, url)
+        self._assert_response(delete(url), f"Unable to delete from={url}")
 
     def delete_all(self, entities: List[E]) -> None:
         """Delete from Firebase all entries provided.
@@ -114,8 +114,8 @@ class FirebaseRepository(Generic[E], metaclass=AbstractSingleton):
 
     def save(self, entity: E) -> None:
         """Saves the given entity at the Firebase store"""
-        ids = '.'.join(entity.identity.values)
-        url = f'{self._config.url(self.table_name())}/{ids}.json'
+        ids = ".".join(entity.identity.values)
+        url = f"{self._config.url(self.table_name())}/{ids}.json"
         payload = entity.as_json()
         log.debug("Saving firebase entry: \n\t|-%s \n\t|-Into %s", entity, url)
         self._assert_response(put(url, payload), f"Unable to put into={url} with json_string={payload}")
@@ -133,31 +133,34 @@ class FirebaseRepository(Generic[E], metaclass=AbstractSingleton):
         limit_to_last: Optional[int] = None,
         start_at: Optional[int | str] = None,
         end_at: Optional[int | str] = None,
-        equal_to: Optional[int | str] = None) -> List[E]:
+        equal_to: Optional[int | str] = None,
+    ) -> List[E]:
         """Return filtered entries from the Firebase store"""
 
-        f_order_by = "orderBy=" + (','.join([f'"{o}"' for o in order_by]) if order_by else '"$key"')
-        f_start_at = f"&startAt={self.quote(start_at)}" if start_at else ''
-        f_end_at = f"&endAt={self.quote(end_at)}" if end_at else ''
-        f_equal_to = f"&equalTo={self.quote(equal_to)}" if equal_to else ''
-        f_limit_first = f"&limitToFirst={limit_to_first}" if limit_to_first else ''
-        f_limit_last = f"&limitToLast={limit_to_last}" if limit_to_last else ''
-        url = f'{self._config.url(self.table_name())}.json?' \
-              f'{f_order_by}{f_start_at}{f_end_at}{f_equal_to}{f_limit_first}{f_limit_last}'
-        log.debug('Fetching firebase entries: \n\t|-From %s', url)
+        f_order_by = "orderBy=" + (",".join([f'"{o}"' for o in order_by]) if order_by else '"$key"')
+        f_start_at = f"&startAt={self.quote(start_at)}" if start_at else ""
+        f_end_at = f"&endAt={self.quote(end_at)}" if end_at else ""
+        f_equal_to = f"&equalTo={self.quote(equal_to)}" if equal_to else ""
+        f_limit_first = f"&limitToFirst={limit_to_first}" if limit_to_first else ""
+        f_limit_last = f"&limitToLast={limit_to_last}" if limit_to_last else ""
+        url = (
+            f"{self._config.url(self.table_name())}.json?"
+            f"{f_order_by}{f_start_at}{f_end_at}{f_equal_to}{f_limit_first}{f_limit_last}"
+        )
+        log.debug("Fetching firebase entries: \n\t|-From %s", url)
         response = self._assert_response(get(url), f"Unable to get from={url}")
-        if response.body and response.body != 'null':
+        if response.body and response.body != "null":
             return self.to_entity_list(response.body)
 
         return []
 
     def find_by_id(self, entity_id: Identity) -> Optional[E]:
         """Return the entry specified by ID from the Firebase store, None if no such entry is found."""
-        ids = '.'.join(entity_id.values)
-        url = f'{self._config.url(self.table_name())}/{ids}.json'
-        log.debug('Fetching firebase entry: \n\t|-Id=%s\n\t|-From %s', entity_id, url)
+        ids = ".".join(entity_id.values)
+        url = f"{self._config.url(self.table_name())}/{ids}.json"
+        log.debug("Fetching firebase entry: \n\t|-Id=%s\n\t|-From %s", entity_id, url)
         response = self._assert_response(get(url), f"Unable to get from={url}")
-        if response.body and response.body != 'null':
+        if response.body and response.body != "null":
             return self.to_entity_type(json.loads(response.body))
 
         return None
